# Author: Amandine Cornille
#mail : amandine.cornille@gmail.com
#Draw membership coefficient plot and define K population(Best K inferred with TESS3R or fastSTRUCTURE)
#An individual is assigned to a population if its membership coefficient is > 0.625 for that population
#Last update : 31.10.2020

#library
library(ggplot2)

#setwd
setwd("")

#input : retrieve  Q matrix of membership coefficient for K = 5 clusters [pophelper input]

#popinfo
popdata_aphid <- read.table('pop_info_aphid_ssr.txt', header = T)

#assign for K=5
data<-read.table('K.5.MajorCluster.Q', header=F)
head(data)
#V1     V2     V3     V4     V5
#1 0.0185 0.0082 0.1568 0.0080 0.8086
#2 0.0542 0.0210 0.8713 0.0165 0.0370
#3 0.0125 0.0120 0.0403 0.0163 0.9188
#4 0.0138 0.0138 0.0393 0.0183 0.9147
#5 0.0143 0.0070 0.1243 0.0622 0.7922
#6 0.0122 0.0082 0.0162 0.0162 0.9473

#find the cluster of the max membership coefficient of each individuals
data_max_pos <- max.col(data, ties.method = c("random", "first", "last"))
data_max_pos

######Add max membership coefficient for each individual
max_cluster_aphid <- NA
for (i in 1:582) {
  max_cluster_aphid[i] <- data[i, data_max_pos[i] ]
}

#make it a dataframe
max_cluster_aphid <- data.frame(max_cluster_aphid)

#add ind and pop info
max_cluster_aphid$ID <- seq(1,582,1)
max_cluster_aphid$grp <- data_max_pos
max_cluster_aphid$individuals <- popdata_aphid$Ind
head(max_cluster_aphid)

#max_cluster_aphid ID grp        individuals
#1            0.8086  1   5  Dom_DP_BE_GIN_2_1
#2            0.8713  2   3 Dom_DP_BE_GIN_2_10
#3            0.9188  3   5 Dom_DP_BE_GIN_2_11
#4            0.9147  4   5 Dom_DP_BE_GIN_2_13
#5            0.7922  5   5  Dom_DP_BE_GIN_2_2
#6            0.9473  6   5  Dom_DP_BE_GIN_2_4


#### Plot
ggplot(max_cluster_aphid, aes(x=max_cluster_aphid))+ geom_density(aes(y = ..count..), fill = "red3") +
  scale_x_continuous(name = 'Proportion of assignation',
                     breaks = round(seq(min(max_cluster_aphid$max_cluster_aphid), max(max_cluster_aphid$max_cluster_aphid), by = 0.05),1)) +
  scale_y_continuous(name = 'Density') + theme_bw()



# 2. Define your population with individuals that have a membership coefficient > the threshold you choose

#Threshold = 0.90
ind_assignation_K5 <- max_cluster_aphid[max_cluster_aphid$max_cluster_aphid > 0.9,]
length(ind_assignation_K5[,1]) #406 so 176 admixed individuals 

#Threshold = 0.55
ind_assignation_K5 <- max_cluster_aphid[max_cluster_aphid$max_cluster_aphid > 0.55,]
length(ind_assignation_K5[,1]) #459 so 123 admixed individuals 

#Threshold = 0.625
ind_assignation_K5 <- max_cluster_aphid[max_cluster_aphid$max_cluster_aphid > 0.625,]
length(ind_assignation_K5[,1]) #406 so 176 admixed individuals 

#Define my 5 populations
#Pop 1
pop_1_K5 <- ind_assignation_K5[ind_assignation_K5$grp == '1',4]
length(pop_1_K5)
save(pop_1_K5, file = "pop1")
#Pop 2
pop_2_K5 <- ind_assignation_K5[ind_assignation_K5$grp == '2',4]
length(pop_2_K5)
save(pop_2_K5, file = "pop2")
#Pop 3
pop_3_K5 <- ind_assignation_K5[ind_assignation_K5$grp == '3',4]
length(pop_3_K5)
save(pop_3_K5, file = "pop3")
#Pop 4
pop_4_K5 <- ind_assignation_K5[ind_assignation_K5$grp == '4',4]
length(pop_4_K5)
save(pop_4_K5, file = "pop4")
#Pop 5
pop_5_K5 <- ind_assignation_K5[ind_assignation_K5$grp == '5',4]
length(pop_5_K5)
save(pop_5_K5, file = "pop5")




























